@@ -5,11 +5,15 @@ from pythonik.models.metadata.views import (
     CreateViewRequest,
     UpdateViewRequest,
 )
-from pythonik.models.metadata.view_responses import ViewResponse, ViewListResponse
+from pythonik.models.metadata.view_responses import (
+    ViewResponse,
+    ViewListResponse,
+)
 from pythonik.models.mutation.metadata.mutate import (
     UpdateMetadata,
     UpdateMetadataResponse,
 )
+from pythonik.models.metadata.fields import FieldCreate, FieldUpdate, FieldResponse
 from pythonik.specs.base import Spec
 from typing import Literal, Union, Dict, Any, List
 
@@ -27,6 +31,10 @@ GET_VIEW_PATH = VIEWS_BASE + "{view_id}/"
 UPDATE_VIEW_PATH = GET_VIEW_PATH
 DELETE_VIEW_PATH = GET_VIEW_PATH
 
+# Field paths
+FIELDS_BASE_PATH = "fields/"
+FIELD_BY_NAME_PATH = "fields/{field_name}/"
+
 
 ObjectType = Literal["segments"]
 
@@ -383,7 +391,7 @@ class MetadataSpec(Spec):
             - can_delete_metadata_views
 
         Returns:
-            Response: Empty response with 204 status code
+            Response: An empty response, expecting HTTP 204 No Content on success.
 
         Raises:
             - 400 Bad request
@@ -392,3 +400,138 @@ class MetadataSpec(Spec):
         """
         resp = self._delete(DELETE_VIEW_PATH.format(view_id=view_id), **kwargs)
         return self.parse_response(resp, None)
+
+    # Metadata Field Management
+    # -------------------------
+
+    def create_field(
+        self,
+        field_data: FieldCreate,
+        exclude_defaults: bool = True,
+        **kwargs,
+    ) -> Response:
+        """Create a new metadata field.
+
+        Args:
+            field_data: The data for the new field.
+            exclude_defaults: Whether to exclude default values when dumping Pydantic models.
+            **kwargs: Additional kwargs to pass to the request.
+
+        Returns:
+            Response: An object containing the HTTP response and a `data` attribute
+                      with a `FieldResponse` model instance on success, or `None` on error.
+        """
+        json_data = self._prepare_model_data(
+            field_data, exclude_defaults=exclude_defaults
+        )
+        resp = self._post(FIELDS_BASE_PATH, json=json_data, **kwargs)
+        return self.parse_response(resp, FieldResponse)
+
+    def update_field(
+        self,
+        field_name: str,
+        field_data: FieldUpdate,
+        exclude_defaults: bool = True,
+        **kwargs,
+    ) -> Response:
+        """Update an existing metadata field by its name.
+
+        Args:
+            field_name: The name of the field to update.
+            field_data: The data to update the field with.
+            exclude_defaults: Whether to exclude default values when dumping Pydantic models.
+            **kwargs: Additional kwargs to pass to the request.
+
+        Returns:
+            Response: An object containing the HTTP response and a `data` attribute
+                      with a `FieldResponse` model instance on success, or `None` on error.
+        """
+        json_data = self._prepare_model_data(
+            field_data, exclude_defaults=exclude_defaults
+        )
+        endpoint = FIELD_BY_NAME_PATH.format(field_name=field_name)
+        resp = self._put(endpoint, json=json_data, **kwargs)
+        return self.parse_response(resp, FieldResponse)
+
+    def delete_field(
+        self,
+        field_name: str,
+        **kwargs,
+    ) -> Response:
+        """Delete a metadata field by its name.
+
+        Args:
+            field_name: The name of the field to delete.
+            **kwargs: Additional kwargs to pass to the request.
+
+        Returns:
+            Response: An empty response, expecting HTTP 204 No Content on success.
+        """
+        endpoint = FIELD_BY_NAME_PATH.format(field_name=field_name)
+        resp = self._delete(endpoint, **kwargs)
+        return self.parse_response(resp)
+
+    # Backward compatibility aliases
+    # ------------------------------
+
+    def create_metadata_field(
+        self,
+        field_data: FieldCreate,
+        exclude_defaults: bool = True,
+        **kwargs,
+    ) -> Response:
+        """Create a new metadata field (deprecated, use create_field instead).
+
+        This method is kept for backward compatibility and will be removed in a future version.
+
+        Args:
+            field_data: The data for the new field.
+            exclude_defaults: Whether to exclude default values when dumping Pydantic models.
+            **kwargs: Additional kwargs to pass to the request.
+
+        Returns:
+            Response: An object containing the HTTP response and a `data` attribute
+                      with a `FieldResponse` model instance on success, or `None` on error.
+        """
+        return self.create_field(field_data, exclude_defaults, **kwargs)
+
+    def update_metadata_field(
+        self,
+        field_name: str,
+        field_data: FieldUpdate,
+        exclude_defaults: bool = True,
+        **kwargs,
+    ) -> Response:
+        """Update an existing metadata field by its name (deprecated, use update_field instead).
+
+        This method is kept for backward compatibility and will be removed in a future version.
+
+        Args:
+            field_name: The name of the field to update.
+            field_data: The data to update the field with.
+            exclude_defaults: Whether to exclude default values when dumping Pydantic models.
+            **kwargs: Additional kwargs to pass to the request.
+
+        Returns:
+            Response: An object containing the HTTP response and a `data` attribute
+                      with a `FieldResponse` model instance on success, or `None` on error.
+        """
+        return self.update_field(field_name, field_data, exclude_defaults, **kwargs)
+
+    def delete_metadata_field(
+        self,
+        field_name: str,
+        **kwargs,
+    ) -> Response:
+        """Delete a metadata field by its name (deprecated, use delete_field instead).
+
+        This method is kept for backward compatibility and will be removed in a future version.
+
+        Args:
+            field_name: The name of the field to delete.
+            **kwargs: Additional kwargs to pass to the request.
+
+        Returns:
+            Response: An empty response, expecting HTTP 204 No Content on success.
+        """
+        return self.delete_field(field_name, **kwargs)
